pub struct CheckParseError(pub String);Expand description
Error produced when a check expression cannot be parsed.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for CheckParseError
impl Clone for CheckParseError
Sourcefn clone(&self) -> CheckParseError
fn clone(&self) -> CheckParseError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckParseError
impl Debug for CheckParseError
impl Eq for CheckParseError
Sourceimpl PartialEq for CheckParseError
impl PartialEq for CheckParseError
Sourcefn eq(&self, other: &CheckParseError) -> bool
fn eq(&self, other: &CheckParseError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CheckParseError