Schema/value conversion between the kit model and MongrelDB core.
Structs
- Row
- A kit row, identified by its internal storage row id and column values.
Functions
- core_
row_ to_ json - Build a JSON row from a core row and a kit table definition.
- core_
to_ json - Convert a core cell value back to JSON, guided by the column type.
- json_
to_ core - Convert a JSON value to a core cell value using the column type for guidance.
- pk_
to_ map - Convert a primary-key value into the column values for lookup.
- pk_
value - Extract the primary-key value(s) from a JSON value map.
- row_
to_ core_ cells - Build a core cell vector from a JSON row and kit table definition.
- to_
core_ schema - Convert a kit table to a core schema.