pub struct JoinQuery {
pub table: String,
pub alias: Option<String>,
pub joins: Vec<Join>,
pub filter: Option<Expr>,
pub order_by: Vec<OrderBy>,
pub limit: Option<usize>,
pub offset: Option<usize>,
}Expand description
A nested-loop join query. The result is a list of combined rows; each combined
row is a JSON object keyed by table alias whose values are that source’s row
object (or JSON null for an unmatched right side of a LEFT join). Column
references in filter/order_by/join on must be qualified (alias.column).
Fields
table: Stringalias: Option<String>joins: Vec<Join>filter: Option<Expr>order_by: Vec<OrderBy>limit: Option<usize>offset: Option<usize>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for JoinQuery
impl<'de> Deserialize<'de> for JoinQuery
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<JoinQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<JoinQuery, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for JoinQuery
impl Serialize for JoinQuery
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for JoinQuery