pub struct SetNullUpdate {
pub table: String,
pub pk: String,
pub columns: Vec<String>,
}Expand description
A child row that must be updated to set its foreign-key columns to null.
Fields
table: Stringpk: Stringcolumns: Vec<String>Trait Implementations
Sourceimpl Clone for SetNullUpdate
impl Clone for SetNullUpdate
Sourcefn clone(&self) -> SetNullUpdate
fn clone(&self) -> SetNullUpdate
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SetNullUpdate
impl Debug for SetNullUpdate
impl Eq for SetNullUpdate
Sourceimpl PartialEq for SetNullUpdate
impl PartialEq for SetNullUpdate
Sourcefn eq(&self, other: &SetNullUpdate) -> bool
fn eq(&self, other: &SetNullUpdate) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SetNullUpdate