Delete planning: compute the set of rows affected by a delete, including cascade, set-null, and restrict foreign-key actions.
Structs
- Delete
Plan - Result of planning a delete against a schema.
- Restricted
Constraint - A foreign-key constraint that blocks the delete.
- RowRef
- A row identified for deletion planning.
- SetNull
Update - A child row that must be updated to set its foreign-key columns to null.
Enums
- Planner
Error - Errors returned by delete planning.
Functions
- plan_
delete - Plan the deletion of a single row identified by its table and primary key.