Module schema

Module schema 

Schema/value conversion between the kit model and MongrelDB core.

Structs

Row
A kit row, identified by its internal storage row id and column values.

Functions

core_row_to_json
Build a JSON row from a core row and a kit table definition.
core_to_json
Convert a core cell value back to JSON, guided by the column type.
json_to_core
Convert a JSON value to a core cell value using the column type for guidance.
pk_to_map
Convert a primary-key value into the column values for lookup.
pk_value
Extract the primary-key value(s) from a JSON value map.
row_to_core_cells
Build a core cell vector from a JSON row and kit table definition.
to_core_schema
Convert a kit table to a core schema.